==> haskell-reinterpret-cast-0.1.0-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reinterpret-cast
version: 0.1.0
id: reinterpret-cast-0.1.0-D0xSVvStXSqKH6OHDVrJhM
key: reinterpret-cast-0.1.0-D0xSVvStXSqKH6OHDVrJhM
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/reinterpret-cast
synopsis: Memory reinterpretation casts for Float/Double and Word32/Word64
description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.
    .
    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.
category: Data
abi: 70ae8ae77aa1f4477ae11729db0b886c
exposed: True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI
import-dirs: /usr/lib/ghc-8.6.4/site-local/reinterpret-cast-0.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/reinterpret-cast-0.1.0
hs-libraries: HSreinterpret-cast-0.1.0-D0xSVvStXSqKH6OHDVrJhM
depends:
    array-0.5.3.0 base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock
haddock-html: /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reinterpret-cast-0.1.0-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reinterpret-cast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reinterpret-cast
version: 0.1.0
id: reinterpret-cast-0.1.0-EiIr1PL9Cq2JDuTVGXUiaO
key: reinterpret-cast-0.1.0-EiIr1PL9Cq2JDuTVGXUiaO
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/reinterpret-cast
synopsis: Memory reinterpretation casts for Float/Double and Word32/Word64
description:
    Memory reinterpretation casts for Float\/Double and Word32\/Word64.
    .
    The implementations in the @.Internal@ package are different ways to tackle
    the problem; the @array@ method (current default) is about 5 times faster
    than the @FFI@ method.
category: Data
abi: 43b836533912a670a665c3bb50ade4e7
exposed: True
exposed-modules:
    Data.ReinterpretCast Data.ReinterpretCast.Internal.ImplArray
    Data.ReinterpretCast.Internal.ImplFFI
import-dirs: /usr/lib/ghc-8.6.4/site-local/reinterpret-cast-0.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/reinterpret-cast-0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/reinterpret-cast-0.1.0
hs-libraries: HSreinterpret-cast-0.1.0-EiIr1PL9Cq2JDuTVGXUiaO
depends:
    array-0.5.3.0 base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-reinterpret-cast/html/reinterpret-cast.haddock
haddock-html: /usr/share/doc/haskell-reinterpret-cast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
